On 14 Sep., 20:47, Rosomack <[email protected]> wrote:
> Hi Kay,
>
> this sure sounds like a bug.
> ...
> As for the "slow" part, please make sure that you are building without
> debug symbols. From my experience it had a significant impact on
> performance. The algorithm _is_ slower, but it shouldn't be too bad
> even for big pictures.

My latest build of enblend is MUCH slower than previous versions, no
matter what seam generator I use. Look at this: first, an older
version of enblend built from a tar ball I had on my system:

kfj@Anja:~/Panorama/Piemont 8-9 2011$ enblend --
version
enblend 4.0-753b534c819d
...

kfj@Anja:~/Panorama/Piemont 8-9 2011$ time enblend -o IMG_1723-
IMG_1731.tif IMG_1723-IMG_1731000?.tif
enblend: info: loading next image: IMG_1723-IMG_17310000.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310001.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310002.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310003.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310004.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310005.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310006.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310007.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310008.tif 1/1
enblend: warning: some images are redundant and will not be blended
enblend: info: writing final output

real    1m44.463s
user    1m20.729s
sys     0m5.076s

that's what I am used to. Now the same with the latest build (and it's
built as Relase build):

kfj@Anja:~/Panorama/Piemont 8-9 2011$ _enblend --version
enblend 4.1-48edb6264ad8
...

kfj@Anja:~/Panorama/Piemont 8-9 2011$ time _enblend  --primary-seam-
generator=nearest-feature-transform -o IMG_1723-IMG_1731.tif IMG_1723-
IMG_1731000?.tif
enblend: info: loading next image: IMG_1723-IMG_17310000.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310001.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310002.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310003.tif 1/1
enblend: info: loading next image: IMG_1723-IMG_17310004.tif
1/1
enblend: info: loading next image: IMG_1723-IMG_17310005.tif
1/1
enblend: info: loading next image: IMG_1723-IMG_17310006.tif
1/1
enblend: info: loading next image: IMG_1723-IMG_17310007.tif
1/1
enblend: info: loading next image: IMG_1723-IMG_17310008.tif
1/1
enblend: warning: some images are redundant and will not be
blended
enblend: info: writing final
output

real
11m33.315s
user
20m29.457s
sys
0m6.664s

I suppose something must be wrong. It's taking about 6.66 (ha!
paranoid? 6.66 as long, and 6.66 sec system time) as long as before.
What other causes apart from compiling with Debug (which I didn't) and
the new algorithm (which I didn't use) could cause this slowdown?

Kay

-- 
You received this message because you are subscribed to the Google Groups 
"Hugin and other free panoramic software" group.
A list of frequently asked questions is available at: 
http://wiki.panotools.org/Hugin_FAQ
To post to this group, send email to [email protected]
To unsubscribe from this group, send email to 
[email protected]
For more options, visit this group at http://groups.google.com/group/hugin-ptx

Reply via email to